@@ -1,6 +1,6 @@
 
 
-class MyTestCls:
+class MyTestCls(object):
 	def __init__(self, **kwargs):
 		for k, v in kwargs.items():
 			setattr(self, k, v)
